==> mailjet-client-4.1.1-sources.jar: com/mailjet/client/resource/Messagestatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Messagestatistics {

    public static Resource resource = new Resource("messagestatistics", "");

	public static String AVERAGECLICKDELAY = "AverageClickDelay";
	public static String AVERAGECLICKEDCOUNT = "AverageClickedCount";
	public static String AVERAGEOPENDELAY = "AverageOpenDelay";
	public static String AVERAGEOPENEDCOUNT = "AverageOpenedCount";
	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CAMPAIGNCOUNT = "CampaignCount";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String PROCESSEDCOUNT = "ProcessedCount";
	public static String QUEUEDCOUNT = "QueuedCount";
	public static String SPAMCOMPLAINTCOUNT = "SpamComplaintCount";
	public static String TRANSACTIONALCOUNT = "TransactionalCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String CAMPAIGNID = "CampaignID";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CONTACTEMAIL = "ContactEmail";
	public static String CONTACTID = "ContactID";
	public static String CONTACTLISTID = "ContactListID";
	public static String CUSTOMCAMPAIGN = "CustomCampaign";
	public static String FROM = "From";
	public static String FROMDOMAIN = "FromDomain";
	public static String FROMID = "FromID";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String ISDELETED = "IsDeleted";
	public static String ISNEWSLETTERTOOL = "IsNewsletterTool";
	public static String ISSTARRED = "IsStarred";
	public static String MESSAGESTATUS = "MessageStatus";
	public static String PERIOD = "Period";
	public static String TOTS = "ToTS";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}

==> mailjet-client-4.5.0-sources.jar: com/mailjet/client/resource/Messagestatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Messagestatistics {

    public static Resource resource = new Resource("messagestatistics", "");

	public static String AVERAGECLICKDELAY = "AverageClickDelay";
	public static String AVERAGECLICKEDCOUNT = "AverageClickedCount";
	public static String AVERAGEOPENDELAY = "AverageOpenDelay";
	public static String AVERAGEOPENEDCOUNT = "AverageOpenedCount";
	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CAMPAIGNCOUNT = "CampaignCount";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String PROCESSEDCOUNT = "ProcessedCount";
	public static String QUEUEDCOUNT = "QueuedCount";
	public static String SPAMCOMPLAINTCOUNT = "SpamComplaintCount";
	public static String TRANSACTIONALCOUNT = "TransactionalCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String CAMPAIGNID = "CampaignID";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CONTACTEMAIL = "ContactEmail";
	public static String CONTACTID = "ContactID";
	public static String CONTACTLISTID = "ContactListID";
	public static String CUSTOMCAMPAIGN = "CustomCampaign";
	public static String FROM = "From";
	public static String FROMDOMAIN = "FromDomain";
	public static String FROMID = "FromID";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String ISDELETED = "IsDeleted";
	public static String ISNEWSLETTERTOOL = "IsNewsletterTool";
	public static String ISSTARRED = "IsStarred";
	public static String MESSAGESTATUS = "MessageStatus";
	public static String PERIOD = "Period";
	public static String TOTS = "ToTS";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";
	
	public static final String SOFTBOUNCEDCOUNT = "SoftbouncedCount";
	public static final String HARDBOUNCEDCOUNT = "HardbouncedCount";
	public static final String DEFERREDCOUNT = "DeferredCount";

}
